@@ -2,6 +2,7 @@ import os
 import sys
 import asyncio
 import traceback
+import random
 from datetime import datetime, timedelta
 
 from pyrogram import Client
@@ -65,9 +66,9 @@ class BotManager(Client):
 
     def get_token_index_from_flood_file(self):
         if not os.path.exists("flood.txt"):
-            return 0
+            return random.choice(range(len(self.tokens)))
         now = int(datetime.now(self.TZ).timestamp())
-        available = []
+        flooded = []
         non_flooded = []
         for i in range(len(self.tokens)):
             until = self._flood_data.get(i, 0)
@@ -77,12 +78,12 @@ class BotManager(Client):
                 self.save_flood_data()
                 non_flooded.append((i))
             else:
-                available.append((i, until))
-            if non_flooded != []:
-                return non_flooded[0]
+                flooded.append((i, until))
+        if non_flooded != []:
+            return random.choice(non_flooded)
         logger.warning("All tokens are in flood. Picking the one with the soonest expiry.")
-        available.sort(key=lambda x: x[1])
-        return available[0][0]
+        flooded.sort(key=lambda x: x[1])
+        return flooded[0][0]
     def save_flood_data(self):
         with open('flood.txt', "w") as f:
             for token_index, until in self._flood_data.items():
