@@ -3,5 +3,5 @@ from ._ip import check_public_ip_reachable , get_public_ip
 from ._decorators import authorize
 from ._delete import delete
 from ._ractions import Reacts
-from ._fonts import FontMessageMixin , get_font
+from ._fonts import FontMessageMixin , get_font , web_app_data
 from ._movie_parser import parser
\ No newline at end of file
